synphot
=======

.. image:: https://img.shields.io/badge/ascl-1811.001-blue.svg?colorB=262255
    :target: https://ascl.net/1811.001
    :alt: ascl:1811.001

.. image:: https://zenodo.org/badge/10061216.svg
   :target: https://zenodo.org/badge/latestdoi/10061216
   :alt: DOI: 10.5281/zenodo.5020322

.. image:: https://readthedocs.org/projects/synphot/badge/?version=latest
    :target: https://synphot.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/spacetelescope/synphot_refactor/actions/workflows/ci_workflows.yml/badge.svg?branch=master
    :target: https://github.com/spacetelescope/synphot_refactor/actions/workflows/ci_workflows.yml
    :alt: Github Actions CI Status

.. image:: https://codecov.io/gh/spacetelescope/synphot_refactor/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/spacetelescope/synphot_refactor
    :alt: Coverage results

This is a replacement for IRAF STSDAS SYNPHOT and ASTROLIB PYSYNPHOT,
utilizing Astropy and covering the non-instrument specific portions
of the old packages.
